@@ -428,8 +428,8 @@ class InventoryLine(ModelSQL, ModelView):
 
     @classmethod
     def search_inventory_location(cls, name, clause):
-        nested = clause[0].lstrip(name)
-        return [('inventory.' + name + nested,) + tuple(clause[1:])]
+        nested = clause[0][len(name):]
+        return [('inventory.location' + nested, *clause[1:])]
 
     @fields.depends('inventory', '_parent_inventory.date')
     def on_change_with_inventory_date(self, name=None):
